/***************************************************************************
* Title: Table production for Blattman, Hartman and Blair 2013, "How to Promote Order and Property Rights Under Weak Rule of Law" 
* Date: May 2013
* Replication file
****************************************************************************/

/* 

/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
INSTRUCTIONS FOR REPLICATION:
	1. In 1.1, set up the directory to point to the replication folder on your personal computer.
	2. Run the do-file. It will break at "STOP" before Section 5.0. This preliminary section does the final preparations
	   to the dataset for analysis.
	3. Sections 5.0, 6.0, and 7.0 comprise the main tables, the appendix tables, and the supplementary tables. After 
	   the dataset has been prepared by Section 1.0-4.0, you may highlight any table and run it individually. The output
	   will go to the "Output" folder in the replication folder on your personal computer.
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////


	TABLE OF CONTENTS

	
1.0 PREPARE DATASET

2.0 DEFINE OUTREG PROGRAMS

3.0 DATA ADJUSTMENTS

4.0 VARIABLE CONSTRUCTION

5.0 CONSTRUCT TABLES
	5.1 TABLE 1: KEY OUTCOMES AND CHARACTERISTICS OF RESIDENTS, 2010
	5.2 TABLE 2: LAND DISPUTE AVERAGE TREATMENT EFFECTS	
	5.3 TABLE 3: TREATEMENT HETEROGENEITY WITH INDIVIDUAL CHARACTERISTICS
	5.4 TABLE 4: HETEROGENEITY IN LAND DISPUTES
	5.5 TABLE 5: IMPACTS ON PROPERTY OWNERSHIP AND SECURITY	
	5.6 TABLE 6: IMPACTS ON INTERPERSONAL DISPUTES	
	5.7 TABLE 7: IMPACTS ON COMMUNITY-LEVEL VIOLENCE
	5.8 TABLE 8: IMPACTS ON RESOLUTION NORMS & EGALITARIAN ATTITUDES	
	5.9 TABLE 9: IV ESTIMATE OF RELATION BETWEEN MONTHS SINCE TREATMENT AND DISPUTE OUTCOMES
	5.10 TABLE 10: EFFECT OF INTENSE TREATMENT

6.0 APPENDIX TABLES
	6.1 APPENDIX TABLE 1: BASELINE TESTS OF BALANCE
	6.2 APPENDIX TABLE 2: CORRELATES OF COMPLIANCE
	6.3 APPENDIX TABLE 3: RESIDENT CHARACTERISTICS AT ENDLINE
	6.4 APPENDIX TABLE 4: ROBUSTNESS TO ALTERNATE SPECIFICATIONS
	6.5 APPENDIX TABLE 5: ASSOCIATION BETWEEN ATTENDANCE AND RESOLVING CONFLICT, AFTER CONTROLLING FOR TREATMENT
	6.6 APPENDIX TABLE 6: IMPACTS ON RESOLUTION NORMS & EGALITARIAN ATTITUDES	II
	
7.0 SUPPLEMENTARY TABLES
	7.1 SUPPLEMENTARY TABLE 1: NATIONAL STATISTICS		
	7.2 SUPPLEMENTARY TABLE 2: BASELINE TESTS OF BALANCE FOR INTENSITY OF TREATMENT		
	7.3 SUPPLEMENTARY TABLE 3: BASELINE TESTS OF BALANCE FOR TIMING OF TREATMENT
	7.4 SUPPLEMENTARY TABLE 4: COMPLIANCE RATES
	7.5 SUPPLEMENTARY TABLE 5: LAND DISPUTES DISAGGREGATED BY TYPE
	7.6 SUPPLEMENTARY TABLE 6: TREATEMENT HETEROGENEITY WITH BASELINE CHARACTERISTICS
	7.7 SUPPLEMENTARY TABLE 7: RESOLUTION FORUM ATE (multinomial logit)
	7.8 SUPPLEMENTARY TABLE 8: IV ESTIMATE OF RELATION BETWEEN *LOG* MONTHS SINCE TREATMENT AND DISPUTE OUTCOMES
	7.9 SUPPLEMENTARY TABLE 9: IMPACTS ON RESOLUTION NORMS & EGALITARIAN ATTITUDES	
	7.10 SUPPLEMENTARY TABLE 10: LAND DISPUTE AVERAGE TREATMENT EFFECTS	
	7.11 SUPPLEMENTARY TABLE 11: IMPACTS ON INTERPERSONAL DISPUTES	
		
9.0 GRAVEYARD	
	

*/

// 1.0 PREPARE DATASET

	// 1.1 SET DIRECTORY AND OPEN DATA
	
		// Settings
		
			clear
			clear matrix
			set mem 100m
			set more off
			*set matsize 800
		
		// Set directory
			gl JPC "*SET THE DIRECTORY TO THE REPLICATION FOLDER ON YOUR PERSONAL COMPUTER HERE*"
			
			
		// Open cleaned dataset
			use "$JPC/jpc_analysis.dta", clear
			
		// Set directory for output
			cd "$JPC/Output"
			
			
			
					
	// 1.2 SET GLOBALS
		
			gl date "FINAL"
		
			// Controls
	
				// Individual-level (Residents and Targeted residents) analysis

					gl ate_ctrls "ageover60 age40_60 age20_40 yrs_edu female stranger christian minority cashearn_imputedhst noland land_sizehst farm_sizehst lndtake_dum housetake_dum"

					gl het_ctrls "ageover60 age40_60 age20_40 yrs_edu female stranger christian minority cashearn_imputedhst noland land_sizehst farm_sizehst"
						* excludes any ate_ctrls that are heterogeneity measures
					
					gl het2_ctrls "ageover60 age40_60 age20_40 yrs_edu stranger christian minority cashearn_imputedhst noland land_sizehst farm_sizehst"
						
					gl ate2_ctrols "ageover60 age40_60 age20_40 yrs_edu highinc female highinc literate_ec lowinc cviol_scale_ec clandconf_scale_ec cwitchcraft_scale_ec palaviol_imputed_bc trainee"

					gl indv_char "ageover60 age40_60 age20_40 yrs_edu female stranger christian minority cashearn_imputed noland land_size farm_size lndtake_dum housetake_dum refugee displaced displa_rfugem viol_experienced"			
					** indv char is a catch all global for any and all indv characteristics that should be pooled into the trainee-community dataset in Section 3 below		

				// Leader-level analysis
					gl ate_ctrls_l "ageover60 age40_60 age20_40 highinc female lowinc"			// subset of ctrls available for leaders
					
				// Town level
					gl comm_ctrls "district1-district14 vsmall small small2 small3 quartdummy cedulevel_bc ctownhh_log_el cwealthindex_bc cviol_experienced_bc clndtake_bc cviol_scale_bc clandconf_scale_bc cwitchcraft_scale_bc cpalaviol_imputed_bc cprog_ldr_beliefs_bc cattitudes_tribe_bc crelmarry_bc"

					* For analysis within treated (e.g. Table 8)
					gl comm_ctrls_short "district1-district5 district8-district15 vsmall small small2 small3 cedulevel_bc ctownhh_log_el cwealthindex_bc cviol_experienced_bc clndtake_bc cviol_scale_bc clandconf_scale_bc cwitchcraft_scale_bc cpalaviol_imputed_bc cprog_ldr_beliefs_bc cattitudes_tribe_bc crelmarry_bc"

					
				

	// 1.3 WEIGHTING
		
			// Generate sampling weight: the inverse probability of being sampled
				* s_weight1 is used for community member regressions
				* s_weight2 is used for leader, trainee, and community-level regressions (b/c their probability of seleciton is 1)
				* s_weight3 is used for community member regressions or sum stats at baseline
					* Note: transforming weights to have a mean of 1 changes neither coeffs nor se's.
				
			gen s_weight1=1/(commcount_ec/popest2)
				la var s_weight1 "inverse prob. of selection (endline)"
			
			gen s_weight2=1
				la var s_weight2 "1 for all observations--no weighting for differntial probability of selection within communities"	
	
			gen s_weight3=1/(commcount_bc/popest2)
				la var s_weight3 "inverse prob. of selection (baseline)"
	
			gen s_weight4=s_weight1
			replace s_weight4=1 if TARGETED_RESIDENT==1 | ENDLINE_LEADER==1
				la var s_weight4 "inverse prob. of selection for C; 1 for T & L"
		

// 2.0 DEFINE OUTREG PROGRAMS

	// PROGRAM: ATE outreg command: calls of Y label, calculates Y ctrl mean, extracts ATE coeff and calculates it as a % change.

		cap program drop outreg_ATE
		program def outreg_ATE
						
			// Labels of dependant variables in global Y

				*local lab : var label $Y 
		
			// Control Mean

				qui sum $Y if $Z1==0 & $L1==1 [iweight=$W] 
				local Ymean = r(mean)
				local Ysd = r(sd)
				
			// Treatment Effect, percentage change
				mat X = e(b)
				local atecoeff = el(X,1,1)			
				local pchng = `atecoeff'/`Ymean'
				di `pchng'	
						
			if (`Ymean'!=0) outreg2 using ${table}.xml, label excel ctitle(`lab') aster(se) dec(3) br nocons addstat(Mean in Control Group, 	///
			`Ymean', Avg. Treatment Effect Pcntg, `pchng') addnote($notes) drop($C) append		
			
			if (`Ymean'==0) outreg2 using ${table}.xml, label excel ctitle(`lab') aster(se) dec(3) br nocons addstat(Mean in Control Group, 	///
			`Ymean') addnote($notes) drop($C) append		
			
		end	
		
	// PROGRAM: ATE outreg command (per above) without dropping controls
	
		cap program drop outreg_ATE_ctrls
		program def outreg_ATE_ctrls
						
			// Labels of dependant variables in global Y

				*local lab : var label $Y 
		
			// Control Mean

				qui sum $Y if $Z1==0 & $L1==1 [iweight=$W] 
				local Ymean = r(mean)
				local Ysd = r(sd)
				
			// Treatment Effect, percentage change
				mat X = e(b)
				local atecoeff = el(X,1,1)			
				local pchng = `atecoeff'/`Ymean'
				di `pchng'	
						
			if (`Ymean'!=0) outreg2 using ${table}.xml, label excel ctitle(`lab') aster(se) dec(3) br nocons addstat(Mean in Control Group, 	///
			`Ymean', Avg. Treatment Effect Pcntg, `pchng') addnote($notes) drop() append		
			
			if (`Ymean'==0) outreg2 using ${table}.xml, label excel ctitle(`lab') aster(se) dec(3) br nocons addstat(Mean in Control Group, 	///
			`Ymean') addnote($notes) drop() append		
			
		end	

			
	// PROGRAM: Basic outreg command, does not calc coeffs as a percentage change 

		cap program drop outregJPC3
		program def outregJPC3
						
			// Label of dependant variables

				local lab : var label $Y 
					
			// Control Mean

				qui sum $Y if $Z1==0 & $L1==1
				local Ymean = r(mean)
				*local Ysd = r(sd)
								
			outreg2 using ${table}.xml, label excel ctitle(`lab') aster(se) dec(3) br nocons addstat(Mean in Control Group, ///
			`Ymean') addnote($notes) drop(${ctrls_l} ${ctrls_c} ${ctrls_t} $ctrls2) append
			
		
		end		


		// PROGRAM: Program for Robustness

		cap program drop outreg_robustness
		program def outreg_robustness
						
			// Labels of dependant variables in global Y

				local lab : var label $Y 
		
			// Control Mean

				qui sum $Y if $Z1==0 & $L1==1 & resident==1 [iweight=$W] 
				local Ymean = r(mean)
				local Ysd = r(sd)
				
			// Treatment Effect, percentage change
				mat X = e(b)
				local atecoeff = el(X,1,1)			
				local pchng = `atecoeff'/`Ymean'
				*local pchng = _b[$X1]/`Ymean'
				di `pchng'	
						
						

			if (`Ymean'!=0) outreg2 using ${table}.xml, label excel ctitle(`lab') aster(se) dec(3) br nocons addstat(Mean in Control Group, 	///
			`Ymean', SD in Control Group, `Ysd', Avg. Treatment Effect Pcntg, `pchng') addnote($notes) drop(${ctrls_l} ${ctrls_c} ${ctrls_t} $ctrls2) append		
			
			if (`Ymean'==0) outreg2 using ${table}.xml, label excel ctitle(`lab') aster(se) dec(3) br nocons addstat(Mean in Control Group, 	///
			`Ymean', SD in Contral Group, `Ysd') addnote($notes) drop(${ctrls_l} ${ctrls_c} ${ctrls_t} $ctrls2) append		
			
		end		


// 3.0 DATA ADJUSTMENTS

	// 3.1 COMMUNITIES WITH NO OR LITTLE DATA
			
			/*	
			
			-------------------------------------------------------
			commcode                       town   block   popest2 
			-------------------------------------------------------
			
			Could not be reached/too remote:
			1140                 Boe Geewon       .      2250 
			1430                Zammie Town       .      1720 
			
			Town found abandoned at endline:
			1082                   Baylaybo       .       407 
			
			These communities discovered to have populations less than 50:
			1050   Barttel Jam Koon Village       3        30 
			1312                      Polar       .       300 
			2290                    Kambolo       .        40 
			2850                      Youlu       .        20 
			-------------------------------------------------------
						
				drop if commcode==1050 | commcode==1312 | commcode==2290 | commcode==2850
				drop if commcode==1140 | commcode==1430 | commcode==1082
				
			*/	
	
	
	// 3.2 OUTLIERS & EXTREME VALUES: CAP LAND SIZE VARIABLES AT 95TH PERCENTILE
		
			foreach x of varlist farm_size_et land_size_et farm_size_ec land_size_ec {
	
				local lbl : variable label `x'			
				gen `x'p95c=`x'
				sum `x',d
				replace `x'p95c=r(p95) if `x'>r(p95) & `x'!=.
				la var `x'p95 "`lbl' capped at p95"
			}		
		
	
	// 3.3 IMPUTATION OF MISSING BASELINE DATA 
	
		// Impute median for baseline controls where no TARGETED RESIDENT surveyed at baseline	
		
			// Impute median for continuous vars
			
				foreach x of varlist civic_safe_comm_bt equity_comm_bt agency_bt LOC_bt womens_rights_bt positive_ethnic_view_bt ///
				totalpubcontr_bt group_prtcptn_bt vote05_bt poli_prtcpn_bt restrict_partner_bt abuse_partner_bt {
					qui sum `x', d
					replace `x' = r(p50) if _merge_traineeendbas==1
					
				}
			
			// Impute zero for binaries
				
				foreach x of varlist landconf_dummy_bt crime_dummy_bt palavpubfac_bt witchcraft_dummy_bt palavawatersource_bt ///
				palavayouthelder_bt viol_dummy_bt	{
					replace `x'=0 if _merge_traineeendbas==1
				}
		
	
		// IMPUTE MEDIAN FOR MISC MISSING DATA
		
			foreach x of varlist age_ec age_et {
				qui sum `x',d
				replace `x'=r(p50) if `x'==.
				
			}
			
	
// 4.0 VARIABLE CONSTRUCTION

	// 4.1 TREATMENT VARIABLE CONSTRUCTIONS	

		/*

			1. impl_befroct is a perfectly random variable indicating assignment to treatment of all block 1, 2 and 3 communities plus 4 randomly selected block 4 communities. It is perhaps best renamed assigned_oct.
			
			2. assigned_nov is also a perfectly random variable indicating assignment to treatment of a further 16 block 4 communities, which were implemented concurrently with the survey.
			
			3. 2 communities assigned to treatment before Oct were not treated until Nov/Dec. They have a value of impl_befroct=1. The coding of assigned_nov=1 for these two communities is an error, however, because they were not randomly assigned to November. We should change the value of assigned_nov to be 0 for these two communities and merely have a "treated_oct" variable that equals 1 for all impl_befroct communities except these two.
			
			4. We can create a second endogenous treated variable, treated_nov, indicating who was actually treated during that period. It will equal 1 for the 15 communities that report workshops and 0 for the 1 community that reports no workshop (jpc_treat==0). It can also equal 1 for the two Block 3 communities treated late.
			
			5. For estimation, we have the following choices:
			
				a. estimate ITT of assigned_oct and assigned_nov, but most likely ignore coefficient on assigned_nov
				b. estimate CACE using assigned_oct and assigned_nov as instruments for treated_oct and treated_nov

		*/
		
		gen START_TREATMENT_DATA=.
			la var START_TREATMENT_DATA "========== START TREATMENT DATA ============"

		* Assigned to treatment
	
			ren impl_befroct assigned
				la var assigned "Randomly assigned to be treated by October 2010"	
		
			replace assigned_nov = 0 if assigned==1
				la var assigned_nov "Randomly assigned to be treated during November/December 2010"	

			gen assigned_ever = (assigned==1 | assigned_nov==1)
				la var assigned_ever "Randomly assigned to be treated by November/December 2010"	

			replace intense = 0 if assigned==0
			
			gen blocks1to5 = (block!=0)
				la var blocks1to5 "Randomly assigned to Blocks 1 to 5 (i.e. original assignment)"	

			gen assigned_dropped = (blocks1to5==1 & assigned_ever==0)
				la var assigned_dropped "Randomly assigned to Blocks 1 to 5 but randomly not treated (in reassignment)"	


		* Treated
		
			gen treated_oct=(assigned==1 & jpc_treat>0)
			replace treated_oct=0 if commcode==2010 | commcode==2660 
				la var treated_oct "Treated by October 2010" 

			gen treated_nov=(assigned_nov==1 & jpc_treat>0)
			replace treated_nov=1 if commcode==2010 | commcode==2660 
				la var treated_nov "Treated during Nov/Dec 2010" 
			
			gen treated_ever=(treated_oct==1 | treated_nov==1)
				la var treated_ever "Treated ever" 
		
		* Months since implementation
			
			des impl*_month
			forvalues i = 1/5 {
				gen month`i'=monthly(impl`i'_month, "MY")						// Returns stata assigned # for month of survey between 590 (3/2009) and 611 (12/2010)
				gen month`i'_bfr_impl=611-month`i' 								// Months before December (survey month 611) 
				gen weighted_monthbfr`i'= month`i'_bfr_impl*impl`i'_month_num	// Months before december weighted by number of workshops in that month
			}	
			
			egen tot_workshops=rowtotal(impl1_month_num impl2_month_num impl3_month_num impl4_month_num impl5_month_num ) 					// total number of workshops implemented
			egen tot_month_weight=rowtotal(weighted_monthbfr1 weighted_monthbfr2 weighted_monthbfr3 weighted_monthbfr4 weighted_monthbfr5)	// weighted by months since implementation
	
			gen months_treated=tot_month_weight/tot_workshops
			replace months_treated=0 if assigned_nov==1
				la var months_treated "# months b/t impl. of assigned_oct and _nov communities and the survey (weighted)"
			
			gen lmonths_treated=ln(1+months_treated)
					
			drop month1-tot_month_weight
				
		* Assigned to Block 1, Block 34 dummy and TOT counterparts
			* Note: Some block 3 4 communities not actually assigned due to implementing capacity constraints. 
			* AH and BSM randomized implementation in Block34 and this is accounted for in "assigned"
							
			gen block1 = (block==1) 
				la var block1 "Treatment block 1"

			gen block2 = (block==2) 
				la var block2 "Treatment block 2"

			gen block12 = (block==1 | block==2) 						// all of blocks 1 and 2 were implemented
				la var block12 "Treatment block 1/2"

			gen block3 = (block==3) 
				la var block3 "Treatment block 3"

			gen block4 = (block==4) 
				la var block4 "Treatment block 4"

			gen block5 = (block==5) 
				la var block5 "Treatment block 5"

			gen block4a = (block==4 & assigned==1) 							// includes only those block 4 members assigned to Oct (i.e. reassigned to block 3)
				la var block4a "4 from Block 4 assigned to treatment"

			gen block4b = (assigned_nov==1) 							// includes only those block 16 members assigned to Nov/Dec
				la var block4b "16 from Block 4 assigned to late treatment concurrent with survey"

			gen block4c = (block4==1 & block4a==0 & block4b==0) 							
				la var block4c "16 from Block 4 assigned to late treatment concurrent with survey"
				
			gen block4c5 = (block4c==1 | block5==1) 							
				la var block4c5 "Those randomly reassigned to control"
				

		* % of town implemented for use in spillover analysis 

			gen prop_treated=cond(treated_oct==1, jpc_treat*35/ctownpop_el,0)
				la var prop_treated "% of town treated (endline population estimates)"
			gen prop_treated2=cond(treated_oct==1, jpc_treat*35/ctownpop_bl,0)
				la var prop_treated2 "% of town treated (baseline population estimates)"
			
			gen adultprop_treated=cond(treated_oct ==1, jpc_treat*35/(ctownpop_el*(1.7/3.5)),0) // town population scaled by the % of adult population from http://www.unicef.org/wcaro/wcaro_liberia_fact_CP_indicators.pdf
				la var adultprop_treated "% of town treated (endline population estimates)" 
			gen adultprop_treated2=cond(treated_oct ==1, jpc_treat*35/(ctownpop_bl*(1.7/3.5)),0)
				la var adultprop_treated2 "% of town treated (baseline population estimates)" // town population scaled by the % of adult population from http://www.unicef.org/wcaro/wcaro_liberia_fact_CP_indicators.pdf
					
			pwcorr prop_treated prop_treated2 if COMMLEVEL==1
			sum prop_treated if  treated_oct==1 & COMMLEVEL==1,d					
			sum prop_treated2 if  treated_oct==1 & COMMLEVEL==1,d					
			sum adultprop_treated if  treated_oct==1 & COMMLEVEL==1,d					
			sum adultprop_treated2 if  treated_oct==1 & COMMLEVEL==1,d					
					
		* Where only 1 TARGETED RESIDENT found in community, we dump into catch-all, by county, and use this version of commcode for clustering. 
			
			tab county, gen(county)
			gen commcode_adj=commcode
				la var commcode_adj "Adjusted commcode"
			replace commcode_adj=1001 if commcount_et==1 & county1==1 		// 5 changes made
			replace commcode_adj=1002 if commcount_et==1 & county2==1		// 2 changes made
			replace commcode_adj=1003 if commcount_et==1 & county3==1		// 7 changes made

		* Control variable for if in community w/ other quarter assigned to treatment blocks 1-4
	
			gen quartdummy=cond(commcode==3011 | commcode==2041 | commcode==1082 | commcode==2112 | commcode==3291 | commcode==2431 | commcode==2430 | commcode==1312 | commcode==1321 | commcode==2612 | commcode==2902 | commcode==1472 |commcode==1473,1,0)
				la var quartdummy "Treatment: Control quater in community with other quarter assigned to treatment blocks 1-4"	
		
		
		
	// 4.2 MERGE RESIDENT AND TARGETED RESIDENT DATA
	
		foreach x in $table1 anylndconf_alt2 unrslv_lnd_conf propdest_landconf viol_landconf threat_landconf conflictwith_fam conflictwith_neigh conflictwith_strgr /// 
			conflictwith_oth rslv_lnd_conf satisfied_res rslv_lnd_conf_infrml rslv_lnd_conf_cust rslv_lnd_conf_frml rslv_lnd_conf_adm rslv_lnd_conf_oth rslv_lnd_conf_none /// 
			conflictover_boundary conflictover_inher conflictover_use conflictover_other landconf_propdest landconf_confviol landconf_threatviol mnyconf unrslv_money_conf /// 
			moneyconflict_fam moneyconflict_neigh moneyconflict_strgr moneyconflict_oth rslv_money_conf mnyresfair rslv_money_infrml rslv_money_cust rslv_money_frml rslv_money_adm ///
			rslv_money_oth rslv_money_none anylndconf_alt2 unrslv_lnd_conf propdest_landconf viol_landconf threat_landconf rslv_lnd_conf rslv_lnd_conf_infrml  ///
			satisfied_res anylndconf_alt2 unrslv_lnd_conf propdest_landconf satisfied_res $table3b log_farm_size business_land tree_assets hhqual_index /// 
			land_fiveyrs mnyconf unrslv_mny_conf rslv_money_conf rslv_money_infrml mnyresfair fights_dummy fightweap_dummy tribviol_el strkviol_el /// 
			youthelder_el strkpeac_el interfamlanddisp_el confothtown_el witchkilling_el sasycutl_el sasywitch_el magcourt1_court assertiveprogram_alt ///
			prgrsv_attitudes3 diffdiff_res_e confsolve_res_e nolike_res_e age male yrs_edu notbornintown excom disp_ref viol_experienced lndtake_dum /// 
			housetake_dum land_size noland secure_farm trainee conflictover_boundary_v2 conflictover_inher_v2 conflictover_use_v2 conflictover_other_v2 unrslv_lnd_over_boundary /// 
			unrslv_lnd_over_inher unrslv_lnd_over_use unrslv_lnd_over_other landconf_threatviol_v2 landconf_propdest_v2 landconf_confviol_v2 anylndconf_alt2 propdest_landconf ///
			viol_landconf threat_landconf sevlandconf_dummy unrslv_lnd_conf viol_landconf_dummy landconf_propdest landconf_confviol landconf_threatviol rslv_lnd_conf rslv_lnd_conf_infrml ///
			satisfied_res sprog_gendbeliefs smnrty_landbeliefs sno_ethnic_bias_alt intermarriage land_resolution_type money_resolution_type ///
			$ate_ctrls $ate_ctrls_l $comm_ctrls age land_size farm_size cashearn_imputed displa_rfugem	/// 
			jpc_attend minority under30 prgrsv_attitudes jpc_attend_risk_ls minortribe_assigned jpc_attend_highrisk_ls 	/// 
			money_resolution_type displaced refugee land_resolution_type viol_experienced 	///
			housetake_dum lndtake_dum lndhousetake_dum log_land_size log_farm_size land_size displa_rfugem landless ///
			farm_size farmless propdest_landconf viol_landconf threat_landconf ///
			female age40_60 age20_40 under30 wealthindex chiefrel_dup minority minortribe {
	
					cap local lbl: variable label `x'		
					cap local lbl: variable label `x'_et		
					cap local lbl: variable label `x'_ec		
					cap gen `x'=`x'_et if TARGETED_RESIDENT==1
					cap gen `x'=`x'_ec if ENDLINE_RESIDENT==1
					cap replace `x'=`x'_ec if ENDLINE_RESIDENT==1
					cap replace `x'=`x'_el if ENDLINE_LEADER==1 // LEADERS DONT HAVE ALL VARS THAT TRAINEES AND CITIZENS DO
					cap la var `x' "`lbl'"
			}
	
			la values money_resolution_type money_resolution_type
			la values land_resolution_type land_resolution_type			
		
			foreach y in land_size farm_size cashearn_imputed displa_rfugem {
				local lab : var label `y'
				gen `y'hst = ln(`y'+((`y'^2)+1)^.5)
					la var `y'hst "Hst: `lab'"
			}	

	// 4.3 MISCELLANEOUS VARIABLES
		
		// Indicator for resident or targeted resident
		
			gen resident=cond(TARGETED_RESIDENT==1 | ENDLINE_RESIDENT==1,1,0)
			
			gen targ_or_leader=cond(TARGETED_RESIDENT==1 | ENDLINE_LEADER==1,1,0)					

	
		// Respondent type
	
			gen leader=(ENDLINE_LEADER==1) if ENDLINE_LEADER==1 | ENDLINE_RESIDENT==1 | TARGETED_RESIDENT==1
				la var leader "Leader"

			gen trainee=(TARGETED_RESIDENT==1) if ENDLINE_LEADER==1 | ENDLINE_RESIDENT==1 | TARGETED_RESIDENT==1 // used as control in pooled resident and targeted resident regressions
				la var trainee "Targeted resident"
		
		// Displaced or refugee
		
			gen displ_or_refugee = (displaced==1 | refugee==1)
			 la var displ_or_refugee "Was displaced or a refugee"

		// Town size
		
			replace ctownhh_el=133 if ctownhh_el==. & town=="Baylaybo" 
			replace ctownpop_el=1388 if ctownpop_el==. & town=="Baylaybo" 

			gen ctownhh_log_el=log(ctownhh_el)
			la var ctownhh_log_el "Log of town population"


		// Small community dummies by quartile
				
			xtile quart = ctownpop_el if ENDLINE_LEADER==1 | ENDLINE_RESIDENT==1 | TARGETED_RESIDENT==1 | COMMLEVEL==1, nq(4) 
			
			gen vsmall = (commcode==1050 | commcode==1312 | commcode==2290 | commcode==2850)
			
			gen small = (quart==1) if quart!=.
				la var small "1 if community in 1st quartile for population"
				
			gen small2 = (quart==2) if quart!=.
				la var small2 "1 if community in 2nd quartile for population"
			
			gen small3 = (quart==3) if quart!=.
				la var small3 "1 if community in 3rd quartile for population"
		
			gen small4 = (quart==4) if quart!=.
				la var small4 "1 if community in 4th quartile for population"
						
			drop quart
			placevar ctownhh_log_el small small2 small3 small4, after(quarter)
				
		// Variables for Compliance Rates
			
			/*
			gen ENDLINE_TARGETANDRESIDENT=0
			replace ENDLINE_TARGETANDRESIDENT=1 if TARGETED_RESIDENT==1 | ENDLINE_RESIDENT==1
			lab var ENDLINE_TARGETANDRESIDENT "Person is Targeted Resident or Resident"
	
			gen attend1d=0
			replace attend1d=1 if attend1d_et==1 | attend1d_el==1
			lab var attend1d "Leader or Resident attended at least 1 day"
	
			gen attend4d=0
			replace attend4d=1 if attend4d_et==1 | attend4d_el==1
			lab var attend4d "Leader or Resident attended at least 4 days"
	
			gen attend6d=0
			replace attend6d=1 if attend6d_et==1 | attend6d_el==1
			lab var attend6d "Leader or Resident attended at least 6 days"
			*/
		
								
			
		// Variables for Heterogeneity Analysis
		
			gen comm_small=0
			replace comm_small=1 if small==1 | small2==1
			label var comm_small "indicator of below median size"
			
			gen rltn_to_powerful=0
			replace rltn_to_powerful=1 if chiefrel_dup==1
			label var rltn_to_powerful "Are you related to a big person from before or after the war"
		
			foreach y in female age40_60 age20_40 under30 cwealthindex_bc rltn_to_powerful minority minortribe cgpeace_bc canypeace_bc {
		
			local lab : var label `y'
			gen assigned_`y' = assigned_ever * `y'
			la var assigned_`y' "`lab' * assigned_ever"
			gen treated_`y' = treated_ever * `y'
			la var treated_`y' "`lab' * treated_ever" 
		
			}
				
		// Variables for disaggregated land dispute

			drop cstate_presence_bl- chrighthp_bl  //-- drop variables to keep number below 2047
			
			//Any serious land dispute:
			
			gen conflictover_boundary_v2=0 if anylndconf_alt2!=.
			replace conflictover_boundary_v2=1 if conflictover_boundary==1
			lab var conflictover_boundary_v2 "Cond: Land dispute over land boundaries"
	
			gen conflictover_inher_v2=0 if anylndconf_alt2!=.
			replace conflictover_inher_v2=1 if conflictover_inher==1
			lab var conflictover_inher_v2 "Cond: Land dispute over inheritance"
	
			gen conflictover_use_v2=0 if anylndconf_alt2!=.
			replace conflictover_use_v2=1 if conflictover_use==1
			lab var conflictover_use_v2 "Cond: Land dispute over land use"
		
			gen conflictover_other_v2=0 if anylndconf_alt2!=.
			replace conflictover_other_v2=1 if conflictover_other==1
			lab var conflictover_other_v2 "Cond: Land dispute over other issues"
				
			// Any unresolved land dispute
			
			gen unrslv_lnd_over_boundary=0
			replace unrslv_lnd_over_boundary=1 if unrslv_lnd_conf==1 & conflictover_boundary_v2==1
			label var unrslv_lnd_over_boundary "Cond: unresolved land conflict over land boundaries"
				
			gen unrslv_lnd_over_inher=0
			replace unrslv_lnd_over_inher=1 if unrslv_lnd_conf==1 & conflictover_inher_v2==1
			label var unrslv_lnd_over_inher "Cond: unresolved land conflict over land inheritance"
				
			gen unrslv_lnd_over_use=0
			replace unrslv_lnd_over_use=1 if unrslv_lnd_conf==1 & conflictover_use_v2==1
			label var unrslv_lnd_over_use "Cond: unresolved land conflict over land use"
				
			gen unrslv_lnd_over_other=0
			replace unrslv_lnd_over_other=1 if unrslv_lnd_conf==1 & conflictover_other_v2==1
			label var unrslv_lnd_over_other "Cond: unresolved land conflict over other issue"

			// Land dispute involving violence or threats		

			gen landconf_threatviol_v2=0 if anylndconf_alt2!=.
			replace landconf_threatviol_v2=1 if landconf_threatviol==1
			lab var landconf_threatviol_v2 "Cond: Threat of violence occurred b/c of dispute"
	
			gen landconf_propdest_v2=0 if anylndconf_alt2!=.
			replace landconf_propdest_v2=1 if landconf_propdest==1
			lab var landconf_propdest_v2 "Cond: Property destroyed b/c of dispute"
	
			gen landconf_confviol_v2=0 if anylndconf_alt2!=.	 
			replace landconf_confviol_v2=1 if landconf_confviol==1
			lab var landconf_confviol_v2 "Violence occurred b/c of dispute"
							
							
			// Conflict mediation		
				
			gen diffdiff_res_e=0
			replace diffdiff_res_e=1 if diffdiff_res_ec==1 | diffdiff_res_et==1
			label var diffdiff_res_e "To solve your conflict went to different different people for help"

			gen confsolve_res_e=0
			replace confsolve_res_e=1 if confsolve_res_ec==1 | confsolve_res_et==1
			label var confsolve_res_e "Cond: went to different places because of confusion where to solve conflict"

			gen nolike_res_e=0
			replace nolike_res_e=1 if nolike_res_ec==1 | nolike_res_et==1
			label var nolike_res_e "Cond: went to different places because didn't like first solution"				
			
				
			// Indicators for community-level disputes
			
			gen youthelder_el = cond(pvytheld_el>0 & pvytheld_el!=.,1,0) if ENDLINE_LEADER==1
				label var youthelder_el "Indicator: Any youth-elder disputes"				
			
			gen interfamlanddisp_el = cond(famlndcn_el>0 & famlndcn_el!=.,1,0) if ENDLINE_LEADER==1
				label var interfamlanddisp_el "Indicator: Any inter-family landdisputes"				

			gen confothtown_el = cond(dtwnldcn_el>0 & dtwnldcn_el!=.,1,0) if ENDLINE_LEADER==1
				label var confothtown_el "Indicator: Any conflicts with other towns disputes"				
				
			foreach y in tribviol_el strkviol_el strkpeac_el sasycutl_el witchkilling_el sasywitch_el {
				replace `y'=0 if `y'==. & ENDLINE_LEADER==1
				}
				
				
	// 4.4 TREATMENT INTERACTIONS  -- VARIABLES MISSING NEED TO CHECK THIS
	
		foreach y in displ_or_refugee lndhousetake_dum viol_experienced female under30 minority elder trbl_mkr infl_prsn twn_ldr minrty_ldr wmn_ldr yth_ldr oth_ldr eldr_ldr {
			gen assigned_`y'_`x'=`y'*assigned_ever
			gen treated_`y'_`x'=`y'*treated_ever
			}

	
	// 4.5 ERRONEOUSLY MISSING VALUES
		
			mdesc anylndconf_alt2 unrslv_lnd_conf propdest_landconf viol_landconf threat_landconf rslv_lnd_conf rslv_lnd_conf_infrml satisfied_res if resident==1
			tab unrslv_lnd_conf if rslv_lnd_conf==. & viol_landconf_dummy!=. & resident==1
			replace rslv_lnd_conf=1 if rslv_lnd_conf==. & viol_landconf_dummy!=. & unrslv_lnd_conf==0 & resident==1


// 5.0 CONSTRUCT TABLES

	// Common ATE settings

		svyset [pweight=s_weight2], psu(commcode) strata(county)	// Set survey data specific to each dataset
		gl Z assigned_ever assigned_nov					
		gl Z1 assigned_ever					
		gl L1 resident 
		gl W s_weight2
		gl C $ate_ctrls $comm_ctrls trainee
		gl notes "Omitted regressors include district indicators; demographic characteristics; town-level demographics and baseline conflict measures; and a targeted resident dummy."

STOP		

	
	// 5.1 Table 1: KEY OUTCOMES AND CHARACTERISTICS OF RESIDENTS, 2010

		// Residents and targeted residents
	
				global table table1a_$date
				cap erase $table.xml
				cap erase $table.txt	
	
				cap matrix drop A
				foreach var in anylndconf_alt2 unrslv_lnd_conf propdest_landconf viol_landconf threat_landconf conflictwith_fam conflictwith_neigh conflictwith_strgr conflictwith_oth rslv_lnd_conf satisfied_res rslv_lnd_conf_infrml rslv_lnd_conf_cust rslv_lnd_conf_frml /// 
				rslv_lnd_conf_adm rslv_lnd_conf_oth rslv_lnd_conf_none conflictover_boundary conflictover_inher conflictover_use conflictover_other landconf_propdest landconf_confviol landconf_threatviol mnyconf unrslv_money_conf moneyconflict_fam moneyconflict_neigh moneyconflict_strgr moneyconflict_oth rslv_money_conf mnyresfair rslv_money_infrml rslv_money_cust rslv_money_frml rslv_money_adm rslv_money_oth rslv_money_none {
				
				* Sample mean and SD
					qui sum `var' if ENDLINE_RESIDENT==1 [iweight=$W] 
					local `var'm=r(mean)		
					local `var'n=r(N)
							
				matrix m`var' = (``var'm', ``var'n')
				matrix list m`var'
				matrix A = nullmat(A)\ m`var'
	
			}		
			
			cap matrix list A
	
			* Set column and row names
				local cnames `" "Mean" "Obs" "' 
	
				local rname
				foreach var in anylndconf_alt2 unrslv_lnd_conf propdest_landconf viol_landconf threat_landconf conflictwith_fam conflictwith_neigh conflictwith_strgr conflictwith_oth rslv_lnd_conf satisfied_res rslv_lnd_conf_infrml rslv_lnd_conf_cust rslv_lnd_conf_frml /// 
				rslv_lnd_conf_adm rslv_lnd_conf_oth rslv_lnd_conf_none conflictover_boundary conflictover_inher conflictover_use conflictover_other landconf_propdest landconf_confviol landconf_threatviol mnyconf unrslv_money_conf moneyconflict_fam moneyconflict_neigh moneyconflict_strgr moneyconflict_oth rslv_money_conf mnyresfair rslv_money_infrml rslv_money_cust rslv_money_frml rslv_money_adm rslv_money_oth rslv_money_none {
					 
	
						local lbl : variable label `var'
						local rname `" `rname' "`lbl'" "'
					}	
			
			// Save table	
	
			xml_tab A, save("$table.xml") sheet(`g', color(1)) append noisily cnames(`cnames') rnames(`rname') font("Times New Roman" 12) ///
			title (Table 1: Key outcomes and characteristics of residents, 2010) cw(0 225, 1 50, 2 50, 3 50, 4 50, 5 50, 6 50, 7 50, 8 50) ///
			format((SCLR0) (SCCR0 NBCR2 NBCR2 NBCR2 NBCR2 NBCR2)) note("Note: Results include all residents and targeted residents, pooled")
	
	
		// Town-level (using leaders as unit of analysis)
	
			global table table1b_$date
			cap erase $table.xml
			cap erase $table.txt	
		
			cap matrix drop A
			foreach var in tribviol_el strkviol_el youthelder_el strkpeac_el interfamlanddisp_el confothtown_el witchkilling_el sasycutl_el {
			
				* Sample mean and SD
				qui sum `var' if ENDLINE_LEADER==1
				local `var'm=r(mean)		
				local `var'n=r(N)	
						
				matrix m`var' = (``var'm', ``var'n')
				matrix list m`var'
				matrix A = nullmat(A)\ m`var'
		
				}		
			
			cap matrix list A
	
			* Set column and row names
			local cnames `" "Sample Mean" "Sample N" "' 
	
			local rname
			foreach var in tribviol_el strkviol_el youthelder_el strkpeac_el interfamlanddisp_el confothtown_el witchkilling_el sasycutl_el {	 
	
					local lbl : variable label `var'
					local rname `" `rname' "`lbl'" "'
				}	
		
			// Save table	
	
			xml_tab A, save("$table.xml") sheet(`g', color(1)) append noisily cnames(`cnames') rnames(`rname') font("Times New Roman" 10) ///
			title (Table 2: Key outcomes and characteristics of towns, 2010) cw(0 225, 1 40, 2 40, 3 40, 4 40, 5 40, 6 40, 7 40, 8 40) ///
			format((SCLR0) (SCCR0 NBCR2 NBCR2 NBCR2 NBCR2 NBCR2))
		

	// 5.2 Table 2: LAND DISPUTE AVERAGE TREATMENT EFFECTS	

		gl table table2_$date // define file name
		cap erase $table.xml
		cap erase $table.txt
			
		mdesc anylndconf_alt2 unrslv_lnd_conf propdest_landconf viol_landconf threat_landconf rslv_lnd_conf rslv_lnd_conf_infrml satisfied_res $ate_ctrls $comm_ctrls trainee if $L1==1
		
		foreach y in anylndconf_alt2 unrslv_lnd_conf propdest_landconf viol_landconf threat_landconf rslv_lnd_conf rslv_lnd_conf_infrml satisfied_res {
	
			gl Y `y'
	
			qui svy: ivregress 2sls `y' $C (treated_ever treated_nov = $Z) if $L1==1
				outreg_ATE													
			}
		
		cap erase $table.txt
		
	// 5.3 TABLE 3: TREATMENT HETEROGENEITY WITH INDIVIDUAL CHARACTERISTICS
	
		
		gl table table3_$date // define file name
		cap erase $table.xml
		cap erase $table.txt			

		foreach y in anylndconf_alt2 unrslv_lnd_conf propdest_landconf satisfied_res {

			gl Y `y'
			gl notes "Omitted regressors include district indicators; demographic characteristics; town-level demographics and baseline conflict measures; and a targeted resident dummy."
	
			qui svy:  regress `y' assigned_ever assigned_female female $het2_ctrls trainee if $L1==1
				outreg_ATE_ctrls
			
			qui svy:  regress `y' assigned_ever assigned_age40_60 age40_60 $het2_ctrls trainee if $L1==1
				outreg_ATE_ctrls
				
			qui svy:  regress `y' assigned_ever assigned_age20_40 age20_40 $het2_ctrls trainee if $L1==1
				outreg_ATE_ctrls
			
			qui svy:  regress `y' assigned_ever assigned_under30 under30 $het2_ctrls trainee if $L1==1
				outreg_ATE_ctrls
						
			qui svy:  regress `y' assigned_ever assigned_cwealthindex_bc cwealthindex_bc $het2_ctrls trainee if $L1==1
				outreg_ATE_ctrls
						
			qui svy:  regress `y' assigned_ever assigned_minority minority $het2_ctrls trainee if $L1==1
				outreg_ATE_ctrls
				
			qui svy:  regress `y' assigned_ever assigned_minortribe minortribe $het2_ctrls trainee if $L1==1
				outreg_ATE_ctrls
				
			qui svy:  regress `y' assigned_ever assigned_canypeace_bc canypeace_bc $het2_ctrls trainee 
				outreg_ATE_ctrls
				
			qui svy:  regress `y' assigned_ever assigned_cgpeace_bc cgpeace_bc $het2_ctrls trainee 
				outreg_ATE_ctrls
			}
		
		cap erase $table.txt	
			
	// 5.4 Table 4: HETEROGENEITY IN LAND DISPUTES
	
		gl table table4_$date // define file name
		cap erase $table.xml
		cap erase $table.txt			
		
		foreach y in anylndconf_alt2 unrslv_lnd_conf propdest_landconf viol_landconf threat_landconf rslv_lnd_conf rslv_lnd_conf_infrml satisfied_res {
	
			gl Y `y'
			gl C $het_ctrls $comm_ctrls trainee
			
			qui svy: ivregress 2sls `y' lndhousetake_dum $C (treated_ever treated_nov treated_lndhousetake_dum = $Z assigned_lndhousetake_dum) if $L1==1
				outreg_ATE	
		 			
			}
		
		cap erase $table.txt
		
		gl C $ate_ctrls $comm_ctrls trainee
		
		
		
	

							
	// 5.5 Table 5: IMPACTS ON PROPERTY OWNERSHIP AND SECURITY
				
		gl table table5_$date
		cap erase $table.xml
		cap erase $table.txt
	
		set more off			
	
		foreach y in log_farm_size business_land tree_assets hhqual_index land_fiveyrs {
	
			gl Y `y'

			qui svy: ivregress 2sls `y' $C (treated_ever treated_nov = $Z) if $L1==1
				outreg_ATE													
	
			}
	
			cap erase $table.txt
	
				
				
	// 5.6 Table 6: IMPACTS ON INTERPERSONAL DISPUTES		
		
			gl table table6_$date // define file name
			cap erase $table.xml
			cap erase $table.txt
				
		foreach y in mnyconf unrslv_mny_conf rslv_money_conf rslv_money_infrml mnyresfair fights_dummy fightweap_dummy {
	
			gl Y `y'

			qui svy: ivregress 2sls `y' $C (treated_ever treated_nov = $Z) if $L1==1
				outreg_ATE	
	
			}
	
			cap erase $table.txt
	
	
	// 5.7 Table 7: IMPACTS ON COMMUNITY-LEVEL VIOLENCE 
		
		gl table table7_$date // define file name
		cap erase $table.xml
		cap erase $table.txt
		
		gl L1 ENDLINE_LEADER
		gl C $comm_ctrls
	
		foreach y in tribviol_el strkviol_el youthelder_el strkpeac_el interfamlanddisp_el confothtown_el witchkilling_el sasycutl_el sasywitch_el  {
	
			gl Y `y'

			qui svy: ivregress 2sls `y' $C (treated_ever treated_nov = $Z) if $L1==1
				outreg_ATE							
				
				}
			
			cap erase $table.txt
		
		gl L1 "resident"
		gl C $ate_ctrls $comm_ctrls trainee

	
	// 5.8 Table 8: IMPACTS ON RESOLUTION NORMS & EGALITARIAN ATTITUDES	
				
		gl table table8_$date
			cap erase $table.xml
			cap erase $table.txt
	
		foreach y in magcourt1_court assertiveprogram_alt prgrsv_attitudes3 {
	
			gl Y `y'
			gl C $ate_ctrls_l $comm_ctrls trainee				

			qui svy: ivregress 2sls `y' $C (treated_ever treated_nov = $Z) if $L1==1
				outreg_ATE	
	
			}
	
		cap erase $table.txt
	
	
	// 5.9 TABLE 9: IV ESTIMATE OF RELATION BETWEEN MONTHS SINCE TREATMENT AND DISPUTE OUTCOMES
		
		gl table table9_$date // define file name
		cap erase $table.xml
		cap erase $table.txt
				
		foreach y in anylndconf_alt2 unrslv_lnd_conf propdest_landconf satisfied_res mnyconf unrslv_mny_conf rslv_money_conf rslv_money_infrml mnyresfair fights_dummy fightweap_dummy {
	
			local lab : var label `y' 
	
			gl notes "Omitted regressors include district indicators; demographic characteristics; town-level demographics and baseline conflict measures; and a targeted resident dummy."
	
			qui svy: ivregress 2sls `y' $ate_ctrls $comm_ctrls_short trainee (months_treated = block1 block2 block3) if resident==1 & assigned_ever==1
				outreg2 using $table.xml, label excel ctitle(`lab') aster(se) dec(4) br nocons addnote($notes) drop($ate_ctrls $comm_ctrls_short trainee) append		
		
		}
		
		foreach y in tribviol_el strkviol_el youthelder_el strkpeac_el interfamlanddisp_el confothtown_el witchkilling_el sasycutl_el sasywitch_el {
	
			local lab : var label `y' 
	
			gl notes "Omitted regressors include district indicators; demographic characteristics; town-level demographics and baseline conflict measures; and a targeted resident dummy."
	
			qui svy: ivregress 2sls `y' $comm_ctrls_short (months_treated = block1 block2 block3) if ENDLINE_LEADER==1 & assigned_ever==1
				outreg2 using $table.xml, label excel ctitle(`lab') aster(se) dec(4) br nocons addnote($notes) drop($comm_ctrls_short) append		

		}
		
		
		cap erase $table.txt
	
	
	// 5.10 TABLE 10: EFFECT OF INTENSE TREATEMENT
		
		gl table atable5_$date // define file name
		cap erase $table.xml
		cap erase $table.txt
				
		foreach y in jpc_attend anylndconf_alt2 unrslv_lnd_conf propdest_landconf satisfied_res $table3b mnyconf unrslv_mny_conf rslv_money_conf rslv_money_infrml mnyresfair fights_dummy fightweap_dummy magcourt1_court assertiveprogram_alt prgrsv_attitudes3 diffdiff_res_e confsolve_res_e nolike_res_e {
	
			local lab : var label `y' 
	
			gl notes "Omitted regressors include district indicators; demographic characteristics; town-level demographics and baseline conflict measures; and a targeted resident dummy."
	
			qui svy: reg `y' assigned_ever intense assigned_nov $C if $L1==1
				outreg2 using $table.xml, label excel ctitle(`lab') aster(se) dec(4) br nocons addnote($notes) drop($ate_ctrls $comm_ctrls trainee) append		
			}
		
		cap erase $table.txt	
				
// 6.0 APPENDIX TABLES

	
	// 6.1 APPENDIX TABLE 1: BASELINE TESTS OF BALANCE
		
		tab assigned_ever intense if COMMLEVEL==1 // 16/26 intense communities treated -- the others were in blocks 4 & 5 and not treated	

		gl atable1 "age_bc male_bc yrs_edu_bc muslim_bc traditional_bc christian_bc wealthindex_bc landless_bc farmless_bc prog_ldr_beliefs_bc attitudes_tribe_bc relmarry_dup_bc refugee_bc displaced_bc viol_experienced_bc lndtake_dum_bc landconf_dummy_bc moneyconflict_bc crime_dummy_bc witchcraft_dummy_bc palawater_dum_bc anypeace_bc gpeace_bc  "
		gl atable1b "ctownpop_bl cedulevel_bc cnum_tribes_bc cprop_domgroup_bc cwealthindex_bc cfacilities_bl ctot_resources_bl croad_dist_rainy_bl cviol_experienced_bc clndtake_bc cprog_ldr_beliefs_bc cattitudes_tribe_bc canypeace_bc cgpeace_bc crelmarry_bc cviol_scale_bc clandconf_scale_bc cwitchcraft_scale_bc cpalaviol_imputed_bc cstrkpeac_dummy_bl ccoll_viol_bl ctribal_conf_bl ccapital_offense_bl"
		
			global table atable1_$date
			cap erase $table.xml
			cap erase $table.txt	
			
			cap matrix drop A
			
			foreach var in age male yrs_edu notbornintown excom disp_ref viol_experienced lndtake_dum housetake_dum land_size noland secure_farm trainee {
			
			* Sample mean
				qui sum `var' [iweight=$W]
				local `var'm=r(mean)		
				local `var'n=r(N)
				
			* Treatment and control mean
				qui sum `var' if assigned_ever==1 & BASELINE_RESIDENT==1 [iweight=$W] 
				local `var'mt=r(mean)		
				qui sum `var' if assigned_ever==0 & BASELINE_RESIDENT==1 [iweight=$W] 
				local `var'mc=r(mean)

			* Diff in Means
				*local `var'diff = ``var'mt' - ``var'mc'		

			* Diff in Means (Regression-based) and P-values	
				qui svy: reg `var' assigned_ever county1 county2
				local `var'b=_b[assigned_ever]
				local t = _b[assigned_ever]/_se[assigned_ever]
				local `var'pv = 2*ttail(e(df_r), abs(`t'))			

			matrix m`var' = (``var'm', ``var'mt', ``var'mc', ``var'b', ``var'pv')
			matrix list m`var'
			matrix A = nullmat(A)\ m`var'
	
		}		
		
		foreach var in $atable1b {
						
				qui sum `var' if COMMLEVEL==1
				local `var'm=r(mean)
				
				qui sum `var' if assigned_ever==1 & COMMLEVEL==1
				local `var'mt=r(mean)		
	
				qui sum `var' if assigned_ever==0 & COMMLEVEL==1
				local `var'mc=r(mean)		
				
			* Diff in Means
				*local `var'diff = ``var'mt' - ``var'mc'		
			
			* P-values	
				qui svy: reg `var' assigned_ever county1 county2 if COMMLEVEL==1
				local `var'b=_b[assigned_ever]
				local t = _b[assigned]/_se[assigned]
				local `var'pv = 2*ttail(e(df_r), abs(`t'))			

			matrix m`var' = (``var'm', ``var'mt', ``var'mc', ``var'b', ``var'pv')
			matrix list m`var'
			matrix A = nullmat(A)\ m`var'
		}
	
		cap matrix list A
	
		* Set colum and row names
			local cnames `" "Sample Mean" "Treatment Mean" "Control Mean" "Difference (Regression)" "P Value" "' 
	
			local rname
			foreach var in age male yrs_edu notbornintown excom disp_ref viol_experienced lndtake_dum housetake_dum land_size noland secure_farm trainee $atable1b {	 
	
					local lbl : variable label `var'
					local rname `" `rname' "`lbl'" "'
				}	
		
		// Save table	
	
		xml_tab A, save("$table.xml") sheet(`g', color(1)) append noisily cnames(`cnames') rnames(`rname') font("Times New Roman" 12) ///
		title ("Appendix Table 1: Baseline Tests of Balance") cw(0 225, 1 40, 2 40, 3 40, 4 40, 5 40, 6 40, 7 40, 8 40) ///
		format((SCLR0) (SCCR0 NBCR2 NBCR2 NBCR2 NBCR2 NBCR2))
	
	
	// 6.2 APPENDIX TABLE 2: CORRELATES OF COMPLIANCE
	
			gl atable2c "age yrs_edu female stranger christian minority cashearn_imputed noland farm_size viol_experienced lndtake_dum housetake_dum displaced refugee cedulevel_bc ctownhh_log_el cnum_tribes_bc cwealthindex_bc cviol_experienced_bc clndtake_bc clandconf_scale_bc"
			gl atable2t "age yrs_edu female stranger christian minority cashearn_imputed noland farm_size viol_experienced lndtake_dum housetake_dum displaced refugee cedulevel_bc ctownhh_log_el cnum_tribes_bc cwealthindex_bc cviol_experienced_bc clndtake_bc clandconf_scale_bc"
			gl atable2l "age female stranger christian minority cashearn_imputed noland land_size lndtake_dum housetake_dum cedulevel_bc ctownhh_log_el cnum_tribes_bc cwealthindex_bc cviol_experienced_bc clndtake_bc clandconf_scale_bc"
			
		// Note 17 trainees found at endline were not found at baseline, thus we don't have data for war exper variables (measured only at baseline) to see this, "tab _merge_traineeendbas"
				mdesc $atable2c if resident==1 
				mdesc $atable2c if resident==1 & _merge_traineeendbas!=1
						
			gl table atable2_$date // define file name
			cap erase $table.xml
			cap erase $table.txt
			
			gl Y jpc_attend
			local lab : var label $Y 
			gl notes "Omitted regressors include district indicators."
			
			qui svy: reg jpc_attend trainee $atable2c if assigned==1 & resident==1
				outreg2 using $table.xml, label excel ctitle(`lab') aster(se) addnote($notes) dec(3) br nocons drop(district*) append		
			
			qui svy: reg jpc_attend $atable2c if assigned==1 & ENDLINE_RESIDENT==1
				outreg2 using $table.xml, label excel ctitle(`lab') aster(se) addnote($notes) dec(3) br nocons drop(district*) append		
			
			qui svy: reg jpc_attend $atable2t if assigned==1 & TARGETED_RESIDENT==1
				outreg2 using $table.xml, label excel ctitle(`lab') aster(se) addnote($notes) dec(3) br nocons drop(district*) append		
			
			qui svy: reg jpc_attend $atable2l if assigned==1 & leader==1
				outreg2 using $table.xml, label excel ctitle(`lab') aster(se) addnote($notes) dec(3) br nocons drop(district*) append		
	
			cap erase $table.txt


	// 6.3 APPENDIX TABLE 3: RESIDENT CHARACTERISTICS AT ENDLINE
	
		global table atable3_$date
		cap erase $table.xml
		cap erase $table.txt	

		cap matrix drop A

		foreach var in $ate_ctrls trainee {
				qui sum `var' [iweight=$W] if resident==1
				local `var'm=r(mean)
				local `var'sd=r(sd)		
				local `var'n=r(N)
				
			matrix m`var' = (``var'm', ``var'sd', ``var'n')
			matrix list m`var'
			matrix A = nullmat(A)\ m`var'
	
		}		
	
		cap matrix list A
	
		* Set colum and row names
			local cnames `" "Sample Mean" "Std. Dev." "Obs." "' 
	
			local rname
			foreach var in $ate_ctrls trainee {	 
	
					local lbl : variable label `var'
					local rname `" `rname' "`lbl'" "'
				}	
		
		// Save table	
	
		xml_tab A, save("$table.xml") sheet(`g', color(1)) append noisily cnames(`cnames') rnames(`rname') font("Times New Roman" 12) ///
		title ("Appendix Table 1: Baseline Tests of Balance") cw(0 225, 1 40, 2 40, 3 40, 4 40) ///
		format((SCLR0) (SCCR0 NBCR2 NBCR2 NBCR2 NBCR2 NBCR2))


	// 6.4 APPENDIX TABLE 4: ROBUSTNESS TO ALTERNATE SPECIFICATIONS
	
		global table atable4a_$date // define file name
		global ptable atable4b_$date // define file name
		cap erase $table.xml
		cap erase $table.txt
					
		foreach y in anylndconf_alt2 unrslv_lnd_conf propdest_landconf rslv_lnd_conf_infrml satisfied_res mnyconf fights_dummy {
	
			local lab : var label `y' 
			gl notes "Omitted regressors include district indicators unless otherwise indicated."
					
			
			// ATE from main table (CACE OLS w/ controls)
			qui svy: ivregress 2sls `y' $C (treated_ever treated_nov = $Z) if $L1==1
				outreg2 using $table.xml, label excel ctitle(`lab') aster(se) addnote($notes) dec(3) br nocons drop($ate_ctrls $comm_ctrls trainee) append		
							
			// CACE OLS w/ controls
			qui svy: ivregress 2sls `y' $C (treated_ever treated_nov = $Z) if $L1==1
				outreg2 using $table.xml, label excel ctitle("CACE OLS w/ controls") aster(se) addnote($notes) dec(3) br nocons drop($ate_ctrls $comm_ctrls trainee) append		

			// CACE OLS w/o controls (only districts)
			qui svy: ivregress 2sls `y' district1-district14 (treated_ever treated_nov = $Z) if $L1==1
				outreg2 using $table.xml, label excel ctitle("CACE OLS w/o controls") aster(se) addnote($notes) dec(3) br nocons drop($ate_ctrls $comm_ctrls trainee) append		

			// CACE OLS w/ controls and survey weighted by population
			
			svyset [pweight=s_weight3], psu(commcode) strata(county)	// Change survey to s_weight3 

			qui svy: ivregress 2sls `y' $C (treated_ever treated_nov = $Z) if $L1==1
				outreg2 using $table.xml, label excel ctitle("CACE OLS w/ controls and survey weighted by population") aster(se) addnote($notes) dec(3) br nocons drop($ate_ctrls $comm_ctrls trainee) append		

			svyset [pweight=$W], psu(commcode) strata(county)

			// CACE OLS w/ controls - residents only
			qui svy: ivregress 2sls `y' $ate_ctrls $comm_ctrls (treated_ever treated_nov = $Z) if ENDLINE_RESIDENT==1
				outreg2 using $table.xml, label excel ctitle("CACE OLS w/ controls - residents only") aster(se) addnote($notes) dec(3) br nocons drop($ate_ctrls $comm_ctrls trainee) append		

			// ITT w/ ctrls			
			qui svy: reg `y' $Z $C if resident==1 
				outreg2 using $table.xml, label excel ctitle("ITT w/ ctrls") aster(se) addnote($notes) dec(3) br nocons drop($ate_ctrls $comm_ctrls trainee) append		

			// Probit ITT w/ ctrls
			qui svy: probit `y' $Z $C if resident==1
				outreg2 using $table.xml, label excel ctitle("Probit ITT w/ ctrls") aster(se) addnote($notes) dec(3) br nocons drop($ate_ctrls $comm_ctrls trainee) append		

			// CACE - All blocks
			qui svy: ivregress 2sls `y' $C (treated_ever treated_nov = blocks1to5 assigned_nov) if $L1==1
				outreg2 using $table.xml, label excel ctitle("CACE - All blocks") aster(se) addnote($notes) dec(3) br nocons drop($ate_ctrls $comm_ctrls trainee) append		

			// CACE - All blocks individually
			qui svy: ivregress 2sls `y' $C (treated_ever treated_nov = block1 block2 block3 block4a block4b block4c block5) if $L1==1
				outreg2 using $table.xml, label excel ctitle("CACE - All blocks individually") aster(se) addnote($notes) dec(3) br nocons drop($ate_ctrls $comm_ctrls trainee) append		
	
			}
				
			cap erase $table.txt	
			cap erase $ptable.txt	

	
	
	
		
	// 6.5 APPENDIX TABLE 5: ASSOCIATION BETWEEN ATTENDANCE AND RESOLVING CONFLICT, AFTER CONTROLLING FOR TREATMENT
				
			gl ate_ctrls_atable5 "age yrs_edu female stranger christian minority cashearn_imputed noland log_land_size lndtake_dum housetake_dum"
			gl comm_ctrls_atable5 "district2-district15 cedulevel_bc ctownhh_log_el cwealthindex_bc cviol_experienced_bc clndtake_bc cviol_scale_bc clandconf_scale_bc"
			
			gl table atable5_$date // define file name

			set more off
			cap erase $table.xml
			cap erase $table.txt
	
			gl notes "Omitted regressors include district indicators and town-level demographics. Observations are weighted by inverse sampling probability and standard errors are clustered by community and stratified by county"
	
			foreach y in anylndconf_alt2 unrslv_lnd_conf mnyconf fights_dummy {

				local lab: var label `y'
				
				qui svy: ivregress 2sls `y' $ate_ctrls_atable7 trainee $comm_ctrls_atable5 (treated_ever treated_nov = $Z) if resident==1
					outreg2 using $table.xml, label excel ctitle(`lab') aster(se) addnote($notes) dec(3) br nocons drop(district*) append				
					
				qui svy: ivregress 2sls `y' jpc_attend $ate_ctrls_atable7 trainee $comm_ctrls_atable5 (treated_ever treated_nov = $Z) if resident==1
					outreg2 using $table.xml, label excel ctitle(`lab') aster(se) addnote($notes) dec(3) br nocons drop(district*) append				

				}
				
			cap erase $table.txt
				
	// 	6.6 APPENDIX TABLE 6: IMPACTS ON RESOLUTION NORMS & EGALITARIAN ATTITUDES	II

				
		gl table atable6_$date
			cap erase $table.xml
			cap erase $table.txt
	
		gl C $ate_ctrls_l $comm_ctrls trainee				
	
		foreach y in sprog_gendbeliefs smnrty_landbeliefs sno_ethnic_bias_alt intermarriage {
	
			gl Y `y'
	
			qui svy: ivregress 2sls `y' $C (treated_ever treated_nov = $Z) if $L1==1
				outreg_ATE	
	
			}
		
		cap erase $table.txt		
							

			
STOP	
	
// 7.0 SUPPLEMENTARY TABLES
	
	
	
	// 7.1 SUPPLEMENTARY TABLE 1: NATIONAL STATISTICS
		
		*/ Not in Stata
		
			
	// 7.2 SUPPLEMENTARY TABLE 2: BASELINE TESTS OF BALANCE FOR TIMING OF TREATMENT

		tab assigned_ever intense if COMMLEVEL==1 // 16/26 intense communities treated -- the others were in blocks 4 & 5 and not treated	

		gl stable1 "age_bc male_bc yrs_edu_bc muslim_bc traditional_bc christian_bc wealthindex_bc landless_bc farmless_bc prog_ldr_beliefs_bc attitudes_tribe_bc relmarry_dup_bc refugee_bc displaced_bc viol_experienced_bc lndtake_dum_bc landconf_dummy_bc moneyconflict_bc crime_dummy_bc witchcraft_dummy_bc palawater_dum_bc"
		gl stable1b "ctownpop_bl cedulevel_bc cnum_tribes_bc cprop_domgroup_bc cwealthindex_bc cfacilities_bl ctot_resources_bl croad_dist_rainy_bl cviol_experienced_bc clndtake_bc cprog_ldr_beliefs_bc cattitudes_tribe_bc crelmarry_bc cviol_scale_bc clandconf_scale_bc cwitchcraft_scale_bc cpalaviol_imputed_bc cstrkpeac_dummy_bl ccoll_viol_bl ctribal_conf_bl ccapital_offense_bl"
		
			global table stable2_$date
			cap erase $table.xml
			cap erase $table.txt	
			
			cap matrix drop A
			
			foreach var in $stable1 {
			
			* All treated
				qui sum `var' if BASELINE_RESIDENT==1 & (block12==1 | block34== 1) [iweight=$W]
				local `var'm=r(mean)		
				local `var'n=r(N)
				
			* Block 12 and Block34
				qui sum `var' if BASELINE_RESIDENT==1 & block12==1 [iweight=$W]  
				local `var'mc=r(mean)		
								
				qui sum `var' if BASELINE_RESIDENT==1 & block34==1 [iweight=$W]  
				local `var'mt=r(mean)	
				
			* Diff in Means
				local `var'diff = ``var'mc' - ``var'mt'		

			* P-values	
				qui svy: reg `var' block34 county1 county2 if assigned_ever==1 
				local `var'b=_b[block34]
				local t = _b[block34]/_se[block34]
				local `var'pv = 2*ttail(e(df_r), abs(`t'))			

			matrix m`var' = (``var'm', ``var'mc', ``var'mt', ``var'diff', ``var'pv')
			matrix list m`var'
			matrix A = nullmat(A)\ m`var'
	
		}		
		
		foreach var in $stable1b {
		
		* All treated
						
				qui sum `var' if COMMLEVEL==1
				local `var'm=r(mean)
		
		* Block 12 and Block34
		
				qui sum `var' if block12==1 & COMMLEVEL==1
				local `var'mc=r(mean)		
	
				qui sum `var' if block34==1 &  COMMLEVEL==1
				local `var'mt=r(mean)		
				
			* Diff in Means
				local `var'diff = ``var'mc' - ``var'mt'		
			
			* P-values	
				qui svy: reg `var' block34 county1 county2 if COMMLEVEL==1
				local `var'b=_b[block34]
				local t = _b[block34]/_se[block34]
				local `var'pv = 2*ttail(e(df_r), abs(`t'))			

			matrix m`var' = (``var'm', ``var'mc', ``var'mt', ``var'diff', ``var'pv')
			matrix list m`var'
			matrix A = nullmat(A)\ m`var'
		}
	
		cap matrix list A
	
		* Set colum and row names
			local cnames `" "Sample Mean" "Block12" "Block34" "Difference (Regression)" "P Value" "' 
	
			local rname
			foreach var in $stable1 $stable1b {	 
	
					local lbl : variable label `var'
					local rname `" `rname' "`lbl'" "'
				}	
		
		// Save table	
	
		xml_tab A, save("$table.xml") sheet(`g', color(1)) append noisily cnames(`cnames') rnames(`rname') font("Times New Roman" 12) ///
		title ("Appendix Table 2: Baseline test of balance for timing and intensity of treatment") cw(0 225, 1 40, 2 40, 3 40, 4 40, 5 40, 6 40, 7 40, 8 40) ///
		format((SCLR0) (SCCR0 NBCR2 NBCR2 NBCR2 NBCR2 NBCR2))
		
		
		
	// 7.3 SUPPLEMENTARY TABLE 3: BASELINE TESTS OF BALANCE FOR INTENSITY OF TREATMENT
		
		tab assigned_ever intense if COMMLEVEL==1 // 16/26 intense communities treated -- the others were in blocks 4 & 5 and not treated	

		gl stable2 "age_bc male_bc yrs_edu_bc muslim_bc traditional_bc christian_bc wealthindex_bc landless_bc farmless_bc prog_ldr_beliefs_bc attitudes_tribe_bc relmarry_dup_bc refugee_bc displaced_bc viol_experienced_bc lndtake_dum_bc landconf_dummy_bc moneyconflict_bc crime_dummy_bc witchcraft_dummy_bc palawater_dum_bc"
		gl stable2b "ctownpop_bl cedulevel_bc cnum_tribes_bc cprop_domgroup_bc cwealthindex_bc cfacilities_bl ctot_resources_bl croad_dist_rainy_bl cviol_experienced_bc clndtake_bc cprog_ldr_beliefs_bc cattitudes_tribe_bc crelmarry_bc cviol_scale_bc clandconf_scale_bc cwitchcraft_scale_bc cpalaviol_imputed_bc cstrkpeac_dummy_bl ccoll_viol_bl ctribal_conf_bl ccapital_offense_bl"
		
			global table stable3_$date
			cap erase $table.xml
			cap erase $table.txt	
			
			cap matrix drop A
			
			foreach var in $stable2 {
			
			* All treated
				qui sum `var' if BASELINE_RESIDENT==1 & assigned==1 & (intense==1 | intense==0 ) [iweight=$W]
				local `var'm=r(mean)		
				local `var'n=r(N)
				
			* Intense vs. non-intense
				qui sum `var' if BASELINE_RESIDENT==1 & assigned==1 & intense==1 [iweight=$W]  
				local `var'mc=r(mean)		
								
				qui sum `var' if BASELINE_RESIDENT==1 & assigned==1 & intense==0 [iweight=$W]  
				local `var'mt=r(mean)	
				
			* Diff in Means
				local `var'diff = ``var'mc' - ``var'mt'		

			* P-values	
				qui svy: reg `var' intense county1 county2 if assigned_ever==1 
				local `var'b=_b[intense]
				local t = _b[intense]/_se[intense]
				local `var'pv = 2*ttail(e(df_r), abs(`t'))			

			matrix m`var' = (``var'm', ``var'mc', ``var'mt', ``var'diff', ``var'pv')
			matrix list m`var'
			matrix A = nullmat(A)\ m`var'
	
		}		
		
		foreach var in $stable2b {
		
		* All treated
						
				qui sum `var' if COMMLEVEL==1
				local `var'm=r(mean)
		
		* Intense vs. non-intense
		
				qui sum `var' if intense==1 & assigned==1 & COMMLEVEL==1
				local `var'mc=r(mean)		
	
				qui sum `var' if intense==0 &  assigned==1 & COMMLEVEL==1
				local `var'mt=r(mean)		
				
			* Diff in Means
				local `var'diff = ``var'mc' - ``var'mt'		
			
			* P-values	
				qui svy: reg `var' intense county1 county2 if COMMLEVEL==1
				local `var'b=_b[intense]
				local t = _b[intense]/_se[intense]
				local `var'pv = 2*ttail(e(df_r), abs(`t'))			

			matrix m`var' = (``var'm', ``var'mc', ``var'mt', ``var'diff', ``var'pv')
			matrix list m`var'
			matrix A = nullmat(A)\ m`var'
		}
	
		cap matrix list A
	
		* Set colum and row names
			local cnames `" "Sample Mean" "Intense" "Non-Intense" "Difference (Regression)" "P Value" "' 
	
			local rname
			foreach var in $stable2 $stable2b {	 
	
					local lbl : variable label `var'
					local rname `" `rname' "`lbl'" "'
				}	
		
		// Save table	
	
		xml_tab A, save("$table.xml") sheet(`g', color(1)) append noisily cnames(`cnames') rnames(`rname') font("Times New Roman" 12) ///
		title ("Appendix Table 2: Baseline test of balance for timing and intensity of treatment") cw(0 225, 1 40, 2 40, 3 40, 4 40, 5 40, 6 40, 7 40, 8 40) ///
		format((SCLR0) (SCCR0 NBCR2 NBCR2 NBCR2 NBCR2 NBCR2))
		
		
		

	// 7.4 SUPPLEMENTARY TABLE 4: COMPLIANCE RATES
	
		gl heterogeneityII = "assigned_ever jpc_attend attend1d attend4d attend6d"
	
		gl table stable4_$date
	
		cap erase $table.xml
		cap erase $table.txt
   
		cap matrix drop E
	
			foreach var in $heterogeneityII {
			
				qui count if TARGETED_RESIDENT==1 & assigned_ever==1 & `var'==1
				scalar `var'1 = r(N)
								
				qui count if TARGETED_RESIDENT==1 & assigned_ever==0 & `var'==1
				scalar `var'2 = r(N)
			
				qui count if ENDLINE_RESIDENT==1 & assigned_ever==1 & `var'==1
				scalar `var'3 = r(N)
			
				qui count if ENDLINE_RESIDENT==1 & assigned_ever==0 & `var'==1
				scalar `var'4 = r(N)
			
				qui count if ENDLINE_LEADER==1 & assigned_ever==1 & `var'==1
				scalar `var'5 = r(N)
			
				qui count if ENDLINE_LEADER==1 & assigned_ever==0 & `var'==1
				scalar `var'6 = r(N)
			
				qui count if ENDLINE_TARGETANDRESIDENT==1 & assigned_ever==1 & `var'==1
				scalar `var'7 = r(N)

				qui count if ENDLINE_TARGETANDRESIDENT==1 & assigned_ever==0 & `var'==1
				scalar `var'8 = r(N)
		
				matrix E = nullmat(E)\( `var'1, `var'2, `var'3,`var'4,`var'5,`var'6, `var'7, `var'8)
					
			}
		
		local ceq `" "Targeted Resident" "Targeted Resident" "Resident" "Resident" "Leader" "Leader" "Targeted Resident and Resident" "Targeted Resident and Resident" "'
		local cnames `" "Treatment" "No treatment"  "Treatment" "No treatment" "Treatment" "No treatment" "Treatment" "No treatment" "'
		local rnames `" "Assigned Ever" "Attended Ever" "Attended at least 1 day" "Attended at least 4 days" "Attended at least 6 days" "'
		
		xml_tab E, save("$table.xml") replace noisily cnames(`cnames') rnames(`rnames') ceq(`ceq') showeq line(0 2, -1 2) font("Times New Roman" 11) ///
		format((SCLR0) (SCCR0 NBCR2 NBCR2 NBCR2 NBCR2 NBCR2  NBCR2  NBCR2  NBCR2))
		

	// 7.5 	SUPPLEMENTARY TABLE 5: LAND DISPUTES DISAGGREGATED BY TYPE
				
		gl table stable5_$date // define file name
		cap erase $table.xml
		cap erase $table.txt
			
		mdesc anylndconf_alt2 unrslv_lnd_conf propdest_landconf viol_landconf threat_landconf rslv_lnd_conf rslv_lnd_conf_infrml satisfied_res $ate_ctrls $comm_ctrls if resident==1
		
		foreach y in conflictover_boundary_v2 conflictover_inher_v2 conflictover_use_v2 conflictover_other_v2 unrslv_lnd_over_boundary unrslv_lnd_over_inher unrslv_lnd_over_use unrslv_lnd_over_other landconf_threatviol_v2 landconf_propdest_v2 landconf_confviol_v2 {
	
			gl Y `y'
			gl notes "Omitted regressors include district indicators; demographic characteristics; town-level demographics and baseline conflict measures; and a targeted resident dummy."
	
			qui svy: ivregress 2sls `y' $C (treated_ever treated_nov = $Z) if $L1==1
				outreg_ATE													
			}
		
		cap erase $table.txt
	
		*"conflictover_boundary_v2 conflictover_inher_v2 conflictover_use_v2 conflictover_other_v2 unrslv_lnd_over_boundary unrslv_lnd_over_inher unrslv_lnd_over_use unrslv_lnd_over_other landconf_threatviol_v2 landconf_propdest_v2 landconf_confviol_v2"
				

		
	// 7.6 SUPPLEMENTARY TABLE 6: TREATEMENT HETEROGENEITY WITH COMMUNITY CHARACTERISTICS			
		

		foreach y in cedulevel_bc ctownhh_log_el cviol_experienced_bc clndtake_bc cviol_scale_bc clandconf_scale_bc cwitchcraft_scale_bc cpalaviol_imputed_bc cprog_ldr_beliefs_bc cattitudes_tribe_bc crelmarry_bc {
		
			local lab : var label `y'
			gen assigned_`y' = assigned_ever * `y'
			la var assigned_`y' "`lab' * assigned_ever"
			gen treated_`y' = treated_ever * `y'
			la var treated_`y' "`lab' * treated_ever" 
		
		}
		
		gl table stable6_$date // define file name
		cap erase $table.xml
		cap erase $table.txt			

		foreach y in anylndconf_alt2 unrslv_lnd_conf propdest_landconf satisfied_res {

			gl Y `y'
			gl C "" //Note global has been changed
			gl notes "Omitted regressors include district indicators; demographic characteristics; town-level demographics and baseline conflict measures; and a targeted resident dummy."
	
			qui svy: regress `y' assigned_ever assigned_cedulevel_bc cedulevel_bc $het2_ctrls trainee
				outreg_ATE
						
			qui svy: regress `y' assigned_ever assigned_ctownhh_log_el ctownhh_log_el $het2_ctrls trainee
				outreg_ATE	
			
			qui svy:  regress `y' assigned_ever assigned_cwealthindex_bc cwealthindex_bc $het2_ctrls trainee
				outreg_ATE
			
			qui svy:  regress `y' assigned_ever assigned_cviol_experienced_bc cviol_experienced_bc $het2_ctrls trainee
				outreg_ATE
				
			qui svy:  regress `y' assigned_ever assigned_cviol_scale_bc cviol_scale_bc $het2_ctrls trainee
				outreg_ATE
			
			qui svy:  regress `y' assigned_ever assigned_clandconf_scale_bc clandconf_scale_bc $het2_ctrls trainee
				outreg_ATE
				
			qui svy:  regress `y' assigned_ever assigned_cwitchcraft_scale_bc cwitchcraft_scale_bc $het2_ctrls trainee
				outreg_ATE
				
			qui svy:  regress `y' assigned_ever assigned_cpalaviol_imputed_bc cpalaviol_imputed_bc $het2_ctrls trainee
				outreg_ATE
													
			qui svy:  regress `y' assigned_ever assigned_cprog_ldr_beliefs_bc cprog_ldr_beliefs_bc $het2_ctrls trainee
				outreg_ATE
				
			qui svy:  regress `y' assigned_ever assigned_cattitudes_tribe_bc cattitudes_tribe_bc $het2_ctrls trainee
				outreg_ATE
				
			qui svy:  regress `y' assigned_ever assigned_crelmarry_bc crelmarry_bc $het2_ctrls trainee
				outreg_ATE
			
			}
		
		cap erase $table.txt	
	
		gl C $ate_ctrls $comm_ctrls trainee
		
			
	// 7.7 SUPPLEMENTARY TABLE 7: RESOLUTION FORUM ATE (multinomial logit)
	
	* Note: We code the small number of administrative money dispute resolutions into "other"
	replace money_resolution_type=5 if money_resolution_type==4
	
		gl table stable7$date // define file name
		cap erase $table.xml
		cap erase $table.txt
		
		mlogit land_resolution_type assigned_ever assigned_nov $ate_ctrls_l trainee if resident==1 & unrslv_lnd_conf==0, b(1) rrr
			outreg2 using $table.xml, eform label excel aster(se) dec(2) br nocons drop($ate_ctrls_l trainee) append		
		
		mlogit money_resolution_type assigned_ever assigned_nov $ate_ctrls_l trainee if resident==1 & unrslv_mny_conf==0, b(1) rrr
			outreg2 using $table.xml, eform label excel aster(se) dec(2) br nocons drop($ate_ctrls_l trainee) append		
			
		cap erase $table.txt
		
		
	
	// 7.8 SUPPLEMENTARY TABLE 8: IV ESTIMATE OF RELATION BETWEEN *LOG* MONTHS SINCE TREATMENT AND DISPUTE OUTCOMES
		
		gl table stable8_$date // define file name
		cap erase $table.xml
		cap erase $table.txt
				
		foreach y in anylndconf_alt2 unrslv_lnd_conf propdest_landconf satisfied_res mnyconf unrslv_mny_conf rslv_money_conf rslv_money_infrml mnyresfair fights_dummy fightweap_dummy {
	
			local lab : var label `y' 
	
			gl notes "Omitted regressors include district indicators; demographic characteristics; town-level demographics and baseline conflict measures; and a targeted resident dummy."
	
			qui svy: ivregress 2sls `y' $ate_ctrls $comm_ctrls_short trainee (lmonths_treated = block1 block2 block3) if resident==1 & assigned_ever==1
				outreg2 using $table.xml, label excel ctitle(`lab') aster(se) dec(4) br nocons addnote($notes) drop($ate_ctrls $comm_ctrls_short trainee) append		
		
		}
		
			foreach y in tribviol_el strkviol_el youthelder_el strkpeac_el interfamlanddisp_el confothtown_el witchkilling_el sasycutl_el sasywitch_el {
	
			local lab : var label `y' 
	
			gl notes "Omitted regressors include district indicators; demographic characteristics; town-level demographics and baseline conflict measures; and a targeted resident dummy."

			qui svy: ivregress 2sls `y' $comm_ctrls_short (lmonths_treated = block1 block2 block3) if COMMLEVEL==1 & assigned_ever==1
				outreg2 using $table.xml, label excel ctitle(`lab') aster(se) dec(4) br nocons addnote($notes) drop($comm_ctrls_short) append		
		
		}
		
		cap erase $table.txt
	
	// 7.9 SUPPLEMENTARY TABLE 9: IMPACTS ON RESOLUTION NORMS & EGALITARIAN ATTITUDES	
				
		gl table stable9_$date
			cap erase $table.xml
			cap erase $table.txt
	
		foreach y in diffdiff_res_e confsolve_res_e nolike_res_e {
	
			gl Y `y'
			gl C $ate_ctrls_l $comm_ctrls trainee				

			qui svy: ivregress 2sls `y' $C (treated_ever treated_nov = $Z) if $L1==1
				outreg_ATE	
	
			}
	
		cap erase $table.txt
	
	
	
	// 7.10 SUPPLEMENTARY TABLE 10: LAND DISPUTE AVERAGE TREATMENT EFFECTS	
	
	svyset [pweight=s_weight3]

		gl table stable10_$date // define file name
		cap erase $table.xml
		cap erase $table.txt
			
		mdesc anylndconf_alt2 unrslv_lnd_conf propdest_landconf viol_landconf threat_landconf rslv_lnd_conf rslv_lnd_conf_infrml satisfied_res $ate_ctrls $comm_ctrls trainee if $L1==1
		
		foreach y in anylndconf_alt2 unrslv_lnd_conf propdest_landconf viol_landconf threat_landconf rslv_lnd_conf rslv_lnd_conf_infrml satisfied_res {
	
			gl Y `y'
	
			qui svy: ivregress 2sls `y' $C (treated_ever treated_nov = $Z) if $L1==1
				outreg_ATE													
			}
		
		cap erase $table.txt
			
				
	// 7.11 SUPPLEMENTARY TABLE 11: IMPACTS ON INTERPERSONAL DISPUTES		
	
	svyset [pweight=s_weight3]
			gl table stable11_$date // define file name
			cap erase $table.xml
			cap erase $table.txt
				
		foreach y in mnyconf unrslv_mny_conf rslv_money_conf rslv_money_infrml mnyresfair fights_dummy fightweap_dummy {
	
			gl Y `y'

			qui svy: ivregress 2sls `y' $C (treated_ever treated_nov = $Z) if $L1==1
				outreg_ATE	
	
			}
	
			cap erase $table.txt
	 
	 
		

